@@ -51,7 +51,6 @@ class Controller:
     m = {"command":"emit"}
     m["stream"] = None
     m["tuple"] = {}
-    m["meta"] = {}
 
     if(len(args) == 1):
       m["tuple"] = args[0]
@@ -61,15 +60,11 @@ class Controller:
         m["tuple"] = args[1]
       elif isinstance(args[0], dict):
         m["tuple"] = args[0]
-        m["meta"] = args[1]
     elif(len(args) == 3):
       m["stream"] = args[0]
       m["tuple"] = args[1]
-      m["meta"] = args[2]
 
     if isinstance(m["tuple"], Tuple):
-      if m["tuple"].meta != {}:
-        m["meta"] = m["tuple"].meta
       m["tuple"] = m["tuple"].values
 
     if(m["stream"] == None):
@@ -154,11 +149,6 @@ class Controller:
     except:
       self.log("Missing tuple field in emitted JSON object")
       return None
-    try:
-      meta = d["meta"]
-    except:
-      self.log("Missing meta field in emitted JSON object")
-      return None
     full_tuple = Tuple(d)
     return full_tuple
 
