@@ -4,7 +4,6 @@ import json
 
 class Helper:
 
-  META_NAMES = ["id", "confidence", "since", "source"]
   ALLOWED_END_CYCLE_POLICIES= ["null_emit", "explicit"]
   ALLOWED_OUTPUT_FORMATS = ["replace", "merge"]
   ALLOWED_TYPES = ["string", "integer", "float", "double", "boolean", "array", "map"]
@@ -275,9 +274,6 @@ class Helper:
       if not isinstance(colkey, basestring) or re.match('^[\w]+$', colkey) == None :
         msg = ee+"Field names must be non-empty STRINGS in \"%s\"."%(name)+pp
         self.print_error(msg)
-      if(re.match('^v[0-9]+$', colkey) != None or colkey in self.META_NAMES):
-        msg = ee+"\"v[number]\", \"id\", \"confidence\", \"since\" and \"source\" are special names in Zillabyte. Please name your field something else."+pp
-        self.print_error(msg)
       colval = col[colkey]
       if not isinstance(colval, basestring) or colval == "":
         msg = ee+"Field data types must be non-empty STRINGS in \"%s\"."%(name)+pp
